<?php

namespace Drupal\Tests\next\Kernel\Renderer\MainContent;

use Drupal\KernelTests\KernelTestBase;
use Drupal\next\Controllers\NextSiteEntityController;
use Drupal\next\Entity\NextSite;

/**
 * Tests the NextSiteEntityController.
 *
 * @coversDefaultClass \Drupal\next\Controllers\NextSiteEntityController
 *
 * @group next
 */
class NextSiteEntityControllerTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = ['next'];

  /**
   * The next_site entity.
   *
   * @var \Drupal\next\Entity\NextSiteInterface
   */
  protected $nextSite;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $this->nextSite = NextSite::create([
      'label' => 'Blog',
      'id' => 'blog',
      'base_url' => 'https://blog.com',
      'preview_url' => 'https://blog.com/api/preview',
      'preview_secret' => 'one'
    ]);
    $this->nextSite->save();
  }

  /**
   * @covers ::environmentVariables
   */
  public function testEnvironmentVariables() {
    $controller = NextSiteEntityController::create($this->container);
    $build = $controller->environmentVariables($this->nextSite);

    $this->assertEqual(\Drupal::requestStack()->getCurrentRequest()->getSchemeAndHttpHost(), $build['container']['NEXT_PUBLIC_DRUPAL_BASE_URL']['#context']['value']);
    $this->assertEqual(\Drupal::requestStack()->getCurrentRequest()->getHost(), $build['container']['NEXT_IMAGE_DOMAIN']['#context']['value']);
    $this->assertEqual($this->nextSite->uuid(), $build['container']['DRUPAL_SITE_ID']['#context']['value']);
    $this->assertEqual($this->nextSite->getPreviewSecret(), $build['container']['DRUPAL_PREVIEW_SECRET']['#context']['value']);
    $this->assertEqual(\Drupal::configFactory()->get('system.site')->get('page.front'), $build['container']['DRUPAL_FRONT_PAGE']['#context']['value']);
  }

}
